MemoryLayout

Struct MemoryLayout 

pub struct MemoryLayout<A> {
Show 23 fields pub four_state: bool, pub mode: MemoryLayoutMode, pub offsets: FxHashMap<A, usize>, pub widths: FxHashMap<A, usize>, pub is_4states: FxHashMap<A, bool>, pub unpacked_arrays: FxHashMap<A, UnpackedArrayLayout>, pub total_size: usize, pub working_offsets: FxHashMap<A, usize>, pub working_base_offset: usize, pub sparse_offsets: FxHashMap<A, usize>, pub sparse_base_offset: usize, pub sparse_layouts: FxHashMap<A, SparseWorkingLayout>, pub sparse_active_bits_offset: usize, pub sparse_active_capacity: usize, pub merged_total_size: usize, pub triggered_bits_offset: usize, pub triggered_bits_total_size: usize, pub scratch_base_offset: usize, pub scratch_size: usize, pub runtime_event_capacity: usize, pub runtime_event_slot_size: usize, pub runtime_event_buffer_size: usize, pub runtime_event_site_layouts: Vec<RuntimeEventSiteLayout>,
}

Fields

four_state: boolmode: MemoryLayoutModeoffsets: FxHashMap<A, usize>

Stable region offsets. Includes all declared state objects.

widths: FxHashMap<A, usize>is_4states: FxHashMap<A, bool>

Whether each state object has a four-state source type.

unpacked_arrays: FxHashMap<A, UnpackedArrayLayout>total_size: usize

Stable region size in bytes.

working_offsets: FxHashMap<A, usize>

Working region offsets. Includes only actually-used state objects.

working_base_offset: usizesparse_offsets: FxHashMap<A, usize>

Copy-on-write next-state data for dynamically addressed FF targets.

sparse_base_offset: usizesparse_layouts: FxHashMap<A, SparseWorkingLayout>sparse_active_bits_offset: usizesparse_active_capacity: usizemerged_total_size: usizetriggered_bits_offset: usizetriggered_bits_total_size: usizescratch_base_offset: usizescratch_size: usizeruntime_event_capacity: usizeruntime_event_slot_size: usizeruntime_event_buffer_size: usizeruntime_event_site_layouts: Vec<RuntimeEventSiteLayout>

Implementations

Source

impl<A> MemoryLayout<A>
where A: Copy + Eq + Hash + Ord,

pub fn build<S>(source: &S, four_state: bool, mode: MemoryLayoutMode) -> Self
where S: LayoutSource<A>,

pub fn with_backend_scratch(self, scratch_size: usize) -> Self

Append backend-private scratch storage without changing any semantic state offset. Backend planning happens after the backend-neutral state layout has been finalized, so scratch is always the final region.

pub fn plane_size(&self, address: &A) -> usize

pub fn region_base_offset<R>(&self, address: &R) -> usize
where R: RegionedAddress<A>,

pub fn map_static_bit_offset( &self, address: &A, bit_offset: usize, ) -> (usize, usize)

pub fn regioned_static_byte_and_intra<R>( &self, address: &R, bit_offset: usize, ) -> Option<(i32, usize)>
where R: RegionedAddress<A>,